# idwbif
![Build Status](https://github.com/forana/idwbif/actions/workflows/test.yml/badge.svg)

Provides a decorator to make your functions FAST. Don't worry about how it works.
Supports python 3.10+.

```python
from idwbif import make_it_faster

# just add this decorator, and now it's SUPER fast
@make_it_faster
def my_really_cool_function():
    incredibly_slow_and_inefficient_logic()
```

## How does it work?
Don't worry about it.

## License
[WTFPL](https://www.wtfpl.net/)
